#ifndef NT2_INCLUDE_CONSTANTS_SMALLESTPOSVAL_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SMALLESTPOSVAL_HPP_INCLUDED

#include <nt2/constant/include/constants/smallestposval.hpp>

#endif
